# YASARA MOVIE
# TOPIC:    5. Research topics
# TITLE:    5.4. CASP8 meeting on Sardinia 2008/12/04
# REQUIRES: Structure 8.11.1
# AUTHOR:   Elmar Krieger
# LICENSE:  GPL
# DESCRIPTION: A summary of the protein structure prediction tricks used by YASARA during CASP8.

# Set to 1 if you want to create an MPEG movie for YouTube
MPEG=0

Help=1
if MPEG
  Help=1
  Button=300
elif Help
  Button='ContinueButton'
else  
  Button='LeftButton'

# Change working directory to the place of this macro
# (so that we don't have to specify paths when loading stuff).
CD (MacroDir)
CoordSys Left
Projection perspective
Console Off
StickRadius 70
BallStickRadius 50,70
SecStrPar StrandWidth=0.5,StrandHeight=2.2,StrandSlope=0,ArrowHeight=3.5,StrandPerf=50,HelixWidth=0.5,HelixHeight=2.2,HelixSlope=100,HelixPerf=50,HelixSection=Ellipse,TubeRadius=0.4,TubeEllip=0,Gaps=Dotted,ColTrans=Sharp
ColorPar Scheme=SecStr,Helix,Blue
LabelPar Color=Black
PointPar radius=8,plastic=yes 
SurfPar molecular=Gaussian
ColorBG 7b8fbe
HUD Off
Menu off
ScreenSize 1024,768
LightSource 45,45,Ambience=0,Shadow=40
AtomSize 100
SurfPar Resolution=3
#UserInput Off
ColorBonds Grey
Boundary Wall
showlogos='ShowImage logos,0,-688,1024,768,Priority=1'
if MPEG
  # Encode in YouTube resolution
  SaveMPG casp8,X=480,Y=360,FPS=30 
  #SaveMPG casp8_hires,X=640,Y=480,FPS=30 

#Go Trick5

#
# Title Page and Trick 1
#
Trick1:
Clear
if Help
  if !MPEG
    ShowMessage "Many thanks to the assessors for the opportunity to give you a short summary of the tricks used by the YASARA server..."
  else
    ShowMessage "Welcome to a short summary of the tricks used by the YASARA server at CASP8. Press YouTube's Pause button if the text is too fast..."
# Load scene and background
LoadSce island
DelObj SimCell
for image in 'skysea','logos','trick1','sign'
  LoadPNG (image)
ShowImage skysea,0,0,1024,650
(showlogos)
ColorFog 516aa4
Fog 100

# Create the floating buoy
ShowSphere 10,Grey
ShowArrow Start=Point,0,-15,50,End=Point,0,15,50,Radius=1,Heads=0,Color=606060
ShowBox Width=20,Height=20,Depth=2,LeftCol=c0c0c0,FrontCol=None
MoveMesh Box,Y=25
MakeImageObj Sign,sign,20,20
MakeImageObj Trick1,trick1,20,20
MoveMesh Sign Trick1,Y=25,Z=-0.5
RotateObj Trick1,Y=180
SwitchObj Trick1,off
buoy='Box Arrow Sphere Sign Trick1'
MoveObj (buoy),-19,-23,23

#BuildBoard 28,-8,6,10,12,1
BuildBoard 28,-8,30,10,12,1

Wait 1
# Take snapshot here, Eliza!

# Animate the scene
jumps=6
jumpsteps=15
jumpstart=50
jumpend=jumpstart+jumps*jumpsteps
startpos='24.15,8.21,72'
startori='0,21.27,0'
phase=0
done=0
if Help and !MPEG
  ShowButton Continue
while 1
  for i=1 to 400
    phase=(phase+5)%360
    # Animate the HOH waves
    # This was too slow on the 1GHz Pentium 3 laptop used for the presentation
    # and was therefore hardcoded in the undocumented AnimateWaves command
    #for j=40 to 200 step 20
    #  MoveAtom globalZ>(j) globalZ<(j+20) Obj Water,Y=(sin (phase+j*2)*0.2)
    AnimateWaves (phase) 
    # Animate the buoy
    MoveObj (buoy),Y=(sin (phase+100)*0.3)
    OriObj (buoy),Gamma=(sin phase*10)
    if i>300 and i<=350
      # Let Yami blink with the eyes
      Distance CD? CE? CZ Res 17 30,HD? HE? HZ Res 17 30 Obj Yami,bound=Yes,set=(1.+0.4*(i%5))
    else
      # Rotate Yami's antennas
      Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj Yami,bound=Yes,set=(((phase*2)%360)-180)
    # Let Yami jump from time to time
    if i==jumpstart-5
      AutoPosObj yami,21.4,11.5,72,Steps=5,Wait=No
      AutoOriObj yami,-16.69,-1.72,-28.31,Steps=5,Wait=No
    elif i==jumpend
      AutoPosObj yami,(startpos),Steps=5,Wait=No
      AutoOriObj yami,(startori),Steps=5,Wait=No
    elif i>=jumpstart and i<jumpend
      step=(i-jumpstart)%jumpsteps
      PosObj yami,21.4,(sin (180.*step/jumpsteps)*10+11.5),72
      RotateObj yami,Y=(360./(jumps*jumpsteps))
    if (not MPEG and (Button)) or (MPEG and i==400)  
      done=1
    if (phase==0 or phase==180) and done
      # Quit only if buoy is straight
      break 2
    if !MPEG
      Wait 1
    else
      Wait 2

# Zoom in on the sign
x,y,z=PosObj Sign
steps=100
AutoMove ((0.-x)/steps),((-24.-y)/steps),((17.6e0-z)/steps)
Wait (steps)
AutoMove 0,0,0
if Help
  for text in "If you look at the official plot, you can see that YASARA did well along the vertical high resolution axis...",
              "...which includes side-chain and hydrogen bonding accuracy. On the other hand, there is still room for improvements along...",
              "the horizontal low resolution axis, which is Calpha accuracy. That's why I'll only mention the vertically important things."
    ShowMessage (text)
    Wait (Button)
else
  Wait (Button)

# Trick 1: Look at the backside   
AutoRotateObj (buoy),Y=1.5
SwitchObj Trick1,on
Wait 120
AutoRotateObj (buoy),Y=0
if Help
  for text in "Here is trick 1: You know that for a growing number of PDB files, structure factors can be found in the PDB FTP dungeons.",
              "So one can try to re-refine the templates, hoping for improvements. This has been done by my colleague Robbie Joosten.",
              "The result is the PDB-Redo database, which you can find at this URL. And for quite a few models, this improved the quality." 
    ShowMessage (text)
    Wait (Button)
else
  Wait (Button)
LoadPNG coralreef
if Help
  ShowMessage "The next topic are all the fishy HETATMs in the template PDB files, which cause nothing but trouble..."
for i=1 to 80
  Move Z=0.25
  Wait 1
ShowImage coralreef,0,-420,Alpha=0,Priority=0
AutoMoveImage skysea,0,420,Steps=400
AutoMoveImage coralreef,0,0,Steps=400
for i=1 to 401
  Move Y=0.24
  Wait 1

#
# Trick 2
#
Trick2:
Clear
ColorFog 0036b6
Fog 50
LoadPNG coralreef
ShowImage coralreef
fishbubbles=LoadPNG bubbles
LoadPNG coralreef2
ShowImage coralreef2,Priority=1
frontbubbles=LoadPNG bubbles
LoadPNG logos
(showlogos)
LoadPNG trick2
ShowImage trick2,-1024,0,(1024*3),(768*3),Alpha=0,Priority=1
AutoMoveImage trick2,Alpha=100,Steps=100
if Help
  ShowMessage "So the temptation is huge to just kill them, but no, one should really give it a try and care for these poor creatures..."
  
# Animate the air bubbles
ShowImage (fishbubbles),X=(970-409),Y=-1000,Alpha=60,Priority=0
AutoMoveImage (fishbubbles),X=(970-409),Y=1000,Alpha=60,Steps=500,Cycle=JumpBack
ShowImage (frontbubbles),X=-700,Y=-1500,Alpha=60,Priority=1
AutoMoveImage (frontbubbles),X=-700,Y=1500,Alpha=60,Steps=400,Cycle=JumpBack

# Load the fish  
LoadYOb smallmol
PosObj smallmol,12.7,-20,41
ResonateBond all,all
Style BallStick
ColorBonds Order
Cell Auto
Cell 20,40,20
MoveObj SimCell,Y=10
SwitchObj SimCell,off
# Let the small molecules swim in
ForceField AMBER96
TempCtrl Rescale
Temp 800
Cutoff 5.24
LongRange None
Boundary Wall
TimeStep 2,1.5
Wait 1
Sim On
for i=1 to 600
  ForceAtom all,Y=40
  Wait 1
Cell 40,35,30
PosObj SimCell,3,-2.5,41
TempCtrl Anneal
# Pick the first atom of each small molecule as the one that will be pulled
first,last=SpanRes all
for i=first to last
  pullatom(i)=SpanAtom Res (i)
x=-136
w=1024+136
h=512
s=100
# Let the molecules swim
Sim On
step=1
if Help and !MPEG
  ShowButton Continue
while 1
  # Choose a random pulling direction
  for i=first to last
    for j='x' to 'z'
      pullforce(j)(i)=(rnd 700 + 1000)*(round (rnd 1)*2-1)
  # Pull for 500 simulation cycles
  for i=1 to 500
    for j=first to last
      ForceAtom (pullatom(j)),(pullforcex(j)),(pullforcey(j)),(pullforcez(j))
    if (!MPEG and (Button)) or (MPEG and i==500)
      if step==1
        if Help
          ShowMessage "This boils down to the following protocol: Assign bond orders, add hydrogens, optimize them using semi-empirical QM..."
        LoadPNG autosmiles
        #SwapImage autosmiles,logos
        ShowImage autosmiles,(x),(-h),(w),(h),priority=1
        AutoMoveImage autosmiles,(x),(0),(w),(h),Steps=150
        Wait 150
      if step==2
        if Help
          ShowMessage "...then calculate point charges, and assign the remaining force field parameters using the General AMBER Force Field."
        AutoMoveImage autosmiles,(x),(512),(w),(h),Steps=150
        Wait 150
      if step==3
        if Help
          ShowMessage "To cut the long story short, this allows to fully include ligands in all the following modeling steps."
        AutoMoveImage autosmiles,(x),(1024),(w),(h),Steps=150
        break 2
      if Help and step<3 and !MPEG
        ShowButton Continue
      while LeftButton
        Wait 1
      step=step+1
    Wait 1
for i=1 to 400
  ForceAtom all,Y=-400
  Wait 1
DelAll
DelImage (fishbubbles) (frontbubbles)
AutoMoveImage coralreef coralreef2,264,0,760,570,Steps=150
Wait 150

# Show Myoglobine
if Help
  ShowMessage "If you think of a protein with a heme cofactor, it surely helps if the heme is considered for side-chain prediction and refinement."
LoadSce myoglobin
PosObj 1,-50,0,30
AutoRotateObj 1,Y=0.5
AutoPosObj 1,X=0,Steps=250
AutoRotateObj 1,Y=0
CenterAtom 2438
Cell Auto,Extension=10
SwitchObj SimCell,Off
AutoRotate Y=0.1
TempCtrl Rescale
Temp 298K
Cutoff 7.86
LongRange Coulomb
Boundary Periodic
TimeStep 2,1.5
Sim On
Wait (Button)
Sim Off
ColorBG 0036b6
AutoMoveImage coralreef coralreef2,300,0,640,480,Steps=150
AutoMoveImage trick2,0,0,1024,100,Alpha=0,Steps=100
HideMessage
AutoMove Y=-0.5
Wait 150

#
# Trick 3 - Side-chain prediction
#
Trick3:
InitTrick 3
LoadSce 1ej2
ColorPar Scheme=SecStr,Helix,320
ColorFog 0136b8
Fog 90
Move X=-60
SwitchObj RotGraph,off
AutoRotate Y=0.2
# Get a duplicate to restore SCWRL rotamers
obj=DuplicateObj 1
RemoveObj (obj)
AutoPos X=0,Steps=100
if Help
  ShowMessage "To predict side-chains, YASARA first determines which side-chain rotamers can potentially interact..."
  if !MPEG
    ShowButton Continue
Wait 50
while 1
  for i=1 to 5
    for j=-180 to 176 step 4
      Dihedral N,CA,CB,CG CG1 CG2 Res !Pro,bound=Yes,set=(j)
      Wait 1
      if (!MPEG and (Button)) or (MPEG and i==5)
        break 3
SwitchObj 3,on
if Help
  ShowMessage "...obtaining the rotamer network, which is then solved using the SCWRL algorithm."
Wait 100
Wait (Button)
# Bring back the SCWRL prediction
AddObj (obj)
SwapObj (obj),1
DelObj (obj) RotGraph
# Rotate the object instead of the scene, we want to add a cutplane
AutoRotate Y=0
AutoRotateObj 1,Y=0.2
# Ball the buried residues
surflist()=SurfRes all,Accessible,Unit=Res
reslist()=ListRes all
for i=1 to count reslist
  if surflist(i)<1.0
    BallRes (reslist(i)) and not Arg
if Help
  ShowMessage "Due to SCWRL's simple and fast energy function, this works best for hydrophobic residues in the core, which interact repulsively."   
Wait (Button)
StickRes Protein
SurfPar Molecular=Gaussian
ShowSurf Molecular,Dynamic,OutCol=AtomCol,OutAlpha=100,InCol=008000,InAlpha=100
cut=CutObj 1,SecStr=No
AutoRotateObj (cut),Y=0
RotateObj (cut),Y=45
PosObj (cut),Z=30
AutoPosObj (cut),Z=-30,Steps=200
AutoPosObj (cut),Z=0,Steps=100
if Help
  ShowMessage "Near the surface however, electrostatics, hydrogen bonds and solvation become very important."
Wait (Button)
# Sample side-chains
Clean
HideAtom Element H
if Help
  ShowMessage "YASARA therefore adds another optimization round, where these effects are properly accounted for."
  if !MPEG
    ShowButton Continue
while 1
  for i=1 to 200
    SampleDih Sidechain CA,Method=Staggered,Structures=1,Dihedrals=20,BumpSum=4,Scaffold=5
    Wait 1
    if (!MPEG and (Button)) or (MPEG and i==200)
      break 2
AutoMoveImage trick3,0,0,1024,100,Alpha=0,Steps=100
HideMessage
AutoMove Y=-0.5
Wait 150

#
# Trick 4 - Hydrogen bonding networks
#
Trick4:
InitTrick 4
LoadSce hbondnet1
ColorBonds Order
if Help
  ShowMessage "For over a decade, we have optimized H-bonding networks, using WHAT IF, REDUCE et al. to tune the critical side-chains."
PosObj 1,X=(-18-50), Y=5,  Z=32
PosObj 2,X=(-18+50), Y=-3, Z=32
AutoPosObj 1 2,X=-18,Steps=100
Wait (Button)
HideMessage
AutoMoveImage trick4,0,0,1024,100,Alpha=0,Steps=100
AutoMove Y=-0.5
Wait 100
LoadSce hbondnet5
ColorPar Scheme=SecStr,Helix,320
Pos X=-51
SwitchObj Arrow,Off
AutoPos X=5,Steps=150
textlist()="Ligands were however still kind of a problem. If you look at this NADH, you can see that a model MD refinement would go wrong:",
           "The amide group bound to the nicotine ring is wrong in the template 1A5Z, it will be equally wrong in the model and needs fixing.",
           "The H-bonding network optimizer automatically detects cases like this one and just turns it around."
angle=0
for i=1 to count textlist
  if Help
    ShowMessage (textlist(i))
    if !MPEG
      ShowButton Continue
  if i==2
    LoadPNG spotlight4
    SwapImage spotlight4,logos
    ShowImage spotlight4,Alpha=0,Priority=1
    AutoMoveImage spotlight4,Alpha=70,Steps=100
    SwitchObj Arrow,On
    ShowHBoRes NAD Thr 246,Extend=No
  if i==3
    for i=-10 to -180 step -1
      #RotateObj Arrow,Y=2
      Dihedral 4931,4925,4926,4928,Set=(i)
      Wait 1
  while 1
    for j=1 to 300
      angle=(angle+1)%360
      Rotate Y=(cos angle*-0.05)
      Wait 1
      if (!MPEG and (Button)) or (MPEG and j==300)
        break 2
AutoMoveImage spotlight4,700,130,256,192,Steps=100
AutoMove X=0.5
Wait 100

#
# Trick 5 - Self-parameterizing force field
#
Trick5:
InitTrick 5
if Help
  ShowMessage "MD simulations do not really have a famous track record at CASP, because they tend to move models in the wrong direction."
Wait (Button)
if Help
  ShowMessage "My favorite workaround is a force field whose parameters are optimized while minimizing a set of crystallographic unit cells."
# Show the first steps...
LoadPNG yamber1
ShowImage yamber1,Alpha=0,Priority=1
AutoMoveImage yamber1,Alpha=90,Steps=100
LoadSce 1fus
Free
Color Element
Style Ribbon
StickRes HOH
ShowRes HOH
Pos X=100,Y=0,Z=107
AutoRotate Y=0.25
AutoPos X=33
Wait (Button)
HideMessage
# Show the final steps..
DelImage yamber1
LoadPNG yamber2
ShowImage yamber2,Alpha=90,Priority=1
Style Ball
StickRes HOH
LightSource Alpha=45,Gamma=45,Ambience=85,Shadow=65
ForceField YAMBER3
Boundary periodic
Cutoff 7.86
Longrange None
TempCtrl Rescale
Sim On
Sim Pause
Wait (Button)
# Dispose the scene...
AutoMove Y=-1
AutoMoveImage trick5,0,0,1024,100,Alpha=0,Steps=100
AutoMoveImage yamber2,432,324,160,120,Alpha=0,Steps=100
Wait 100

#
# Trick 5b - The knowledge-based potentials of the YASARA force field
#
Trick5b:
InitTrick '5b'
if Help
  ShowMessage "As soon as the procedure converges, one obtains YAMBER, Yet Another Model Building and Energy Refinement force field."
Wait (Button)
if Help
  ShowMessage "And recently I added knowledge-based dihedral potentials to that, shown here for the Phi dihedral of a serine residue..."
Fog 30
LoadYOb tripeptide
PosObj tripeptide,X=25,Y=-3,Z=15
AutoPosObj tripeptide,X=0,Steps=100
AutoOriObj tripeptide,Alpha=45,Steps=30
MarkAtom 13,15
Wait (Button)
ShowImage trick5b,Priority=0
AutoMoveImage trick5b,Alpha=15,Steps=100
if Movie
  # The YASARA force field is not distributed with YASARA View, load backup
  ForceField AMBER99
  LoadSce kbpotentials
else  
  # Show knowledge-based potentials
  ForceField YASARA  
  ShowKBP 13,15,Name=All,Size=21.0
MoveObj !1,Y=-30
movelist()='-25,-12,63','-24,10,80','0,19,85','24,10,80','25,-10,63'
rotlist()= '90,324,0',  '40,0,0',   '40,0,0', '40,0,0',  '90,80,0'
for i=1 to count movelist
  AutoPosObj (i+1),(movelist(i)),Steps=100,Wait=No
  AutoOriObj (i+1),(rotlist(i)),Steps=100,Wait=No
Wait 100
Cell Auto,Extension=10
SwitchObj SimCell,Off
Cutoff 7.86
Longrange None
Boundary Wall
Sim On
if Help
  ShowMessage "The red arrows obviously indicate the current position of the serine in the various 1D, 2D or 3D potentials during the simulation."
Wait (Button)
AutoMoveImage trick5b,Alpha=0,Steps=100
AutoMoveObj 1,Y=-0.5
AutoMoveObj 2,X=-0.5
AutoMoveObj 3,X=-0.35,Y=0.35
AutoMoveObj 4,Y=0.5
AutoMoveObj 5,X=0.35,Y=0.35
AutoMoveObj 6,X=0.5
Wait 100

#
# Trick 5c - Refinement simulations
#
Trick5c:
InitTrick '5c'
#ShowImage Trick5c,Priority=0
for i=1 to 5
  LoadPNG md101,TransCol=Black
  #ShowImage (3+i),448,336,128,96,Alpha=100,Priority=1
  ShowImage (3+i),456,342,112,84,Alpha=100,Priority=1
if Help
  ShowMessage "For the actual refinement, one runs 100 simulations in parallel, using of course the new force field..."
Wait (Button)
for i=1 to 5
  AutoMoveImage (3+i),-1024,-768,(1024*3),(768*3),Alpha=100,Steps=500
  Wait 40
Wait 250
LoadPNG caspenergy
ShowImage caspenergy,X=256,Y=192,Width=512,Height=384,Alpha=0,Priority=1
AnimateImage caspenergy,Enter=Pop,1000000,Drop,Steps=100
AutoMoveImage caspenergy,X=-256,Y=-300,Width=(1024+512),Height=(768+384),Alpha=100,Steps=100
if Help
  ShowMessage "And then uses another partly knowledge-based energy function to pick the best model for the next refinement round."
Wait 100
DelImage md101
Wait (Button)
AutoMoveImage trick5c,0,0,1024,100,Alpha=0,Steps=100
UnrestImage caspenergy
Wait 100

#
# Thanksgiving
#
Thanksgiving:
ColorPar Scheme=SecStr,Helix,Blue
InitTrick 0
LoadPNG skysea2
SwapImage skysea2,coralreef
ShowImage skysea2,0,768,1024,768,Alpha=100
ColorFog a8b6d6
Fog 100
if Help
  ShowMessage "So these were the five main tricks used during CASP8. Many thanks for watching, and you'll find all the rest at..."

# Create the island
islandheight=20.
islandradius=200
obj=ShowCone BottomRadius=(islandradius*1.5),TopRadius=(0.998*islandradius),Height=(islandheight),Edges=26,
             BottomCol=None,TopCol=None,SideCol=c5a885
MoveObj (obj),Y=(-islandheight/2)
obj=ShowCone BottomRadius=(islandradius*1.5),Height=400,Edges=26,
             BottomCol=None,TopCol=None,SideCol=0000ff
MoveObj (obj),Y=(-islandheight-200)          

# Include the sand
LoadPNG sand
MakeImageObj Sand,sand,(islandradius*2),(islandradius*2)
RotateObj Sand,X=90

# Add the water
LoadPNG waves
MakeImageObj Waves,waves,Width=1000,Height=1000
RotateObj Waves,X=90,Y=20
MoveObj Waves,Y=-(islandheight/2)
AutoRotateObj Waves,Y=0.03
wavestep=0

# Add the wooden board
BuildBoard 200,30,-140,26,30,4

# Create Yami's floating matrass
matsegments=5
matsegradius=4.0
matlength=60
matcol='Green'
for i=0 to matsegments-1
  obj = ShowCone BottomRadius=(matsegradius),Height=(matlength),Edges=12,
                 BottomCol=None,SideCol=(matcol)
  dx=(1.50*matsegradius*((-0.5*(matsegments-1))+i))
  MoveMesh (obj),X=(dx)
  RotateObj (obj),X=90
  NameObj (obj),Matrass
  for j=-1 to 1 step 2
    obj = ShowSphere Radius=(matsegradius),Color=(matcol),Level=2
    MoveMesh (obj),X=(dx),Z=(0.5*j*matlength)
    NameObj (obj),Matrass
obj = ShowSphere Radius=(0.75*matsegradius*matsegments),Color=(matcol),Level=2,ScaleY=0.5,ScaleZ=0.5
MoveMesh (obj),Y=(1.50*matsegradius),Z=(0.5*matlength)
NameObj (obj),Matrass
matshift=225
MoveObj Matrass,X=(matshift),Y=-10,Z=(-matshift)

# Define the look of a palm tree
stamheight=12.
stamradius=3.
stamsegments=8
crown=stamsegments
leafs=5
treeheight=stamheight*stamsegments
treeobjects=stamsegments+leafs

# Define the positions of the palm trees on the island
treeposx=40, -110,  70,  -90, -180, 130, 100
treeposz=40,   80, -60, -120,    0, 130, 0
trees=count treeposx

# Grow the palm trees
for i=1 to trees
  # Create the palm stam  
  for j=0 to stamsegments-1
    obj = ShowCone BottomRadius=(stamradius),TopRadius=(stamradius*2.0),Height=(stamheight),Edges=12,
                   BottomCol=None,TopCol=3a200a,SideCol=986c34
    MoveMesh (obj),Y=(stamheight*j)
    NameObj (obj),Tree(i)(j)
  # Create the palm crown
  for j=1 to leafs
    obj = ShowSphere Radius=(stamradius*2.0),Color=3aae35,Level=2,ScaleY=0.8,ScaleZ=5
    RotateObj (obj),X=8,Y=(j*360/leafs)
    MoveMesh (obj),Y=(treeheight-0.5*stamheight)
    NameObj (obj),Tree(i)(crown)
  # Move the tree to the final location
  MoveObj Tree(i)?,X=(treeposx(i)),Z=(treeposz(i))

# Get Yami
LoadYOb yami
MoveObj yami,Y=22.6

# Place Yami on the matrass
MoveObj Yami,X=(matshift),Y=-25,Z=(-matshift)
MoveAtom Obj Yami,Y=10
RotateObj Yami,Y=90
RotateObj Yami,X=70
AutoRotateObj Yami Matrass,Y=0.2

# Place the scene
cameraheight=30
Move Y=(-cameraheight),Z=80
cenx,ceny,cenz=PosObj yami
Move X=-520,Y=380,Z=220

ColorBG 0037b6
LoadPNG coralreef2
SwapImage coralreef2,logos
ShowImage coralreef2,300,0,640,480,Priority=1
AutoMoveImage coralreef coralreef2,X=0,Y=0,640,480,Steps=150
AutoMove X=1
Wait 150
AutoMove X=0
Wait 20
AutoMove Y=-1.5
AutoMoveImage coralreef coralreef2,X=0,Y=-480,640,480,Steps=250
AutoMoveImage skysea2,0,0,1024,768,Alpha=100,Steps=250
Wait 80
AutoMove X=0.9
AutoMoveImage logos,0,-688,1024,768,Alpha=0,Steps=170
Wait 170
AutoMove X=0,Y=0
HideMessage
treestep=0
LoadPNG thanksgiving
ShowImage thanksgiving,Alpha=0,Priority=1
AutoMoveImage thanksgiving,Alpha=100,Steps=500
if Help and !MPEG
  ShowButton Continue
# Animate the scene
while 1
  for i=1 to 1000
    # Animate the waves
    MoveObj Yami Matrass Waves,Y=((sin wavestep)*0.05)
    wavestep=wavestep+1
    # Animate the palm trees
    for j=1 to stamsegments
      RotateObj Tree?(j),Z=(cos treestep*j*0.02)
    treestep=treestep+1
    Wait 1
    if (!MPEG and (Button)) or (MPEG and i==1000)
      break 2

if MPEG
  SaveMPG Off
  
# Create an 'I love Sardinia' board
# =================================
# Normal size: 26,30,4
def BuildBoard p1,p2,p3,len,height,depth
  # Add the wooden board with instructions
  obj = ShowCone BottomRadius=(0.5*depth),Height=(height),Edges=12,
                BottomCol=None,SideCol=746b6c
  MoveMesh (obj),Y=-(0.5*(len+height))
  ShowBox Width=(len),Height=(len),Depth=(depth),
          LeftCol=746b6c,FrontCol=None,BackCol=746b6c
  LoadPNG ilovesardinia
  MakeImageObj Board,ilovesardinia,(len),(len)
  MoveObj Board,Z=-(0.5*depth)
  NameObj (obj)-(obj+2),Board
  RotateObj Board,Z=-13
  MoveObj Board,(p)

# Initialize tricks 3,4 and 5
# ===========================
def InitTrick t
  global showlogos 
  
  Clear
  ColorBG 0036b6
  LoadPNG coralreef
  ShowImage coralreef,300,0,640,480
  #ShowImage coralreef2,300,0,640,480,Priority=1
  LoadPNG logos
  (showlogos)
  if t
    LoadPNG trick(t)
    ShowImage trick(t),-1024,0,(1024*3),(768*3),Alpha=0,Priority=1
    AutoMoveImage trick(t),Alpha=100,Steps=100
  

"""  
Thanksgiving
All YASARA users, especially those supporting development,
Gert Vriend & WHAT IF,  Roland Dunbrack & SCWRL,
Bert de Groot & CONCOORD, Robbie Joosten & PDB-Redo

Krieger E, Koraimann G, Vriend G (2002) Proteins 47, 393-402
Krieger E, Darden T, Nabuurs S, Finkelstein A, Vriend G (2004) Proteins 57, 678-683
Krieger E, Nielsen JE, Spronk CA, Vriend G (2006) J.Mol.Graph.Model. 25, 481-486

ColorBG 6EC401,ffffff
""" 

